// in micro seconds
#define DETECTIONDELAY 140

// Use macros to turn buzzer (and logging) on / off at compile time
#define BUZZER 1
#define LIVELOGGING 1

#include <ros.h>
#include <std_msgs/UInt32.h>

const int detectorPins[3] = {2, 3, 4};
const int buzzerPin = 5;

unsigned long nextEvents[3] = {0, 0, 0};

ros::NodeHandle  nh;

std_msgs::UInt32 sensor1_msg;
std_msgs::UInt32 sensor2_msg;
std_msgs::UInt32 sensor3_msg;

ros::Publisher gamma1("gamma1", &sensor1_msg);
ros::Publisher gamma2("gamma2", &sensor2_msg);
ros::Publisher gamma3("gamma3", &sensor3_msg);

void setup() {

  nh.initNode();
  nh.advertise(gamma1);
  nh.advertise(gamma2);
  nh.advertise(gamma3);

   
  for(int i=0; i<3; i++) {
    pinMode(detectorPins[i], INPUT);   
    nextEvents[i] = micros() + DETECTIONDELAY;
  }
}


void loop(){
  for(int i=0; i<3; i++) {
    if (digitalRead(detectorPins[i]) == HIGH) {     
      if(micros() > nextEvents[i]) {
        nextEvents[i] = micros() + DETECTIONDELAY;
#if BUZZER
        tone(buzzerPin, 1000, 2);
#endif       


#if LIVELOGGING
        switch(i) {
          case 0: 
            sensor1_msg.data = micros(); 
            gamma1.publish(&sensor1_msg);
            break;
          case 1: 
            sensor2_msg.data = micros(); 
            gamma2.publish(&sensor2_msg);
            break;
          case 2: 
            sensor3_msg.data = micros(); 
            gamma3.publish(&sensor3_msg);
            break;
        }
#endif

      }
    } 
  }


  nh.spinOnce();
  
}
